@@ -45,6 +45,8 @@ DIGRE = re.compile(
 # Set up i18n
 _ = i18n._
 i18n.set_language(mm_cfg.DEFAULT_SERVER_LANGUAGE)
+def D_(s):
+    return s
 
 try:
     True, False
@@ -57,6 +59,7 @@ AUTH_CONTEXTS = (mm_cfg.AuthListAdmin, mm_cfg.AuthSiteAdmin,
 
 
 def main():
+    global _
     doc = Document()
     doc.set_language(mm_cfg.DEFAULT_SERVER_LANGUAGE)
 
@@ -141,7 +144,7 @@ def main():
     doc.set_language(language)
 
     if lenparts < 2:
-        user = cgidata.getfirst('email')
+        user = cgidata.getfirst('email', '').strip()
         if not user:
             # If we're coming from the listinfo page and we left the email
             # address field blank, it's not an error.  Likewise if we're
@@ -158,18 +161,19 @@ def main():
     # If a user submits a form or URL with post data or query fragments
     # with multiple occurrences of the same variable, we can get a list
     # here.  Be as careful as possible.
+    # This is no longer required because of getfirst() above, but leave it.
     if isinstance(user, list) or isinstance(user, tuple):
         if len(user) == 0:
             user = ''
         else:
-            user = user[-1]
+            user = user[-1].strip()
 
     # Avoid cross-site scripting attacks
     safeuser = Utils.websafe(user)
     try:
         Utils.ValidateEmail(user)
     except Errors.EmailAddressError:
-        doc.addError(_('Illegal Email Address: %(safeuser)s'))
+        doc.addError(_('Illegal Email Address'))
         loginpage(mlist, doc, None, language)
         print doc.Format()
         return
@@ -288,13 +292,16 @@ def main():
         # message.
         if cgidata.has_key('password'):
             doc.addError(_('Authentication failed.'))
+            remote = os.environ.get('HTTP_FORWARDED_FOR',
+                     os.environ.get('HTTP_X_FORWARDED_FOR',
+                     os.environ.get('REMOTE_ADDR',
+                                    'unidentified origin')))
+            syslog('security',
+                 'Authorization failed (options): user=%s: list=%s: remote=%s',
+                   user, listname, remote)
             # So as not to allow membership leakage, prompt for the email
             # address and the password here.
             if mlist.private_roster <> 0:
-                remote = os.environ.get('HTTP_FORWARDED_FOR',
-                         os.environ.get('HTTP_X_FORWARDED_FOR',
-                         os.environ.get('REMOTE_ADDR',
-                                        'unidentified origin')))
                 syslog('mischief',
                        'Login failure with private rosters: %s from %s',
                        user, remote)
@@ -578,9 +585,10 @@ address.  Upon confirmation, any other mailing list containing the address
         mlist.Lock()
         needapproval = False
         try:
+            _ = D_
             try:
                 mlist.DeleteMember(
-                    user, 'via the member options page', userack=1)
+                    user, _('via the member options page'), userack=1)
             except Errors.MMNeedApproval:
                 needapproval = True
             except Errors.NotAMemberError:
@@ -592,6 +600,7 @@ address.  Upon confirmation, any other mailing list containing the address
                 pass
             mlist.Save()
         finally:
+            _ = i18n._
             mlist.Unlock()
         # Now throw up some results page, with appropriate links.  We can't
         # drop them back into their options page, because that's gone now!
